import 'package:flextech/search/search_page/interfaces/i_controller_base.dart';
import 'package:flextech/search/search_page/interfaces/i_search_tile.dart';
import 'package:flextech/search/search_page/search_page.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:get/get.dart';

class SearchFieldFormInput extends StatefulWidget {
  final String label;
  final ThemeData theme;
  final FormFieldValidator<String>? validator;
  final Function onClean;
  final Function(ISearchTile) selected;
  final IControllerBase controller;
  final String? text;

  const SearchFieldFormInput(
      {Key? key,
      required this.label,
      required this.theme,
      this.validator,
      required this.onClean,
      required this.selected,
      required this.controller,
      this.text})
      : super(key: key);

  @override
  _SearchFieldFormInputState createState() => _SearchFieldFormInputState();
}

class _SearchFieldFormInputState extends State<SearchFieldFormInput> {
  bool _isValid = true;

  @override
  Widget build(BuildContext context) {
    final _fieldTextEditingController = TextEditingController();

    if (widget.text?.isNotEmpty ?? false) {
      _fieldTextEditingController.text = widget.text!;
    }

    return LayoutBuilder(
        builder: (BuildContext ctx, BoxConstraints constraints) {
      return Padding(
        padding:
            const EdgeInsets.only(left: 8.0, right: 8.0, top: 8.0, bottom: 8.0),
        child: Stack(
          children: [
            Row(
              children: [
                Container(
                  width: constraints.maxWidth - 110,
                  alignment: Alignment.topCenter,
                  child: TextFormField(
                    controller: _fieldTextEditingController,
                    style: widget.theme.textTheme.headline4
                        ?.copyWith(color: widget.theme.colorScheme.secondary),
                    onChanged: (value) {},
                    enabled: false, //
                    validator: (String? text) {
                      if (widget.validator != null) {
                        var value = widget.validator?.call(text);
                        if (value != null) {
                          setState(() {
                            _isValid = value.isEmpty;
                          });
                        }
                      }
                    },
                    textCapitalization: TextCapitalization.words,
                    textAlign: TextAlign.start,
                    cursorColor: widget.theme.colorScheme.primary,
                    decoration: InputDecoration(
                      errorStyle: TextStyle(
                        color:
                            Theme.of(context).errorColor, // or any other color
                      ),
                      contentPadding: EdgeInsets.only(left: 20.0, right: 10),
                      border: OutlineInputBorder(
                        borderSide: BorderSide(
                            color: widget.theme.colorScheme.secondary,
                            width: 1.0),
                      ),
                      disabledBorder: OutlineInputBorder(
                          borderSide: BorderSide(
                              color: (_isValid
                                  ? widget.theme.colorScheme.primary
                                  : Theme.of(context).errorColor),
                              width: 1.0)),
                      focusedBorder: OutlineInputBorder(
                        borderSide: BorderSide(
                            color: widget.theme.colorScheme.primary,
                            width: 1.0),
                      ),
                      focusColor: Colors.red,
                      hintStyle: widget.theme.textTheme.headline1?.copyWith(
                          fontSize: 14,
                          fontWeight: FontWeight.normal,
                          color: widget.theme.colorScheme.secondary),
                      filled: true,
                      labelText: widget.label,
                      labelStyle: widget.theme.textTheme.headline1?.copyWith(
                          fontSize: 15.0,
                          color: widget.theme.colorScheme.secondary),
                      fillColor: Colors.white,
                    ),
                  ),
                ),
              ],
            ),
            Positioned(
              right: 0,
              child: Container(
                width: 90,
                child: Row(
                  children: [
                    SizedBox(
                      width: 10,
                    ),
                    IconButton(
                        icon: Icon(FontAwesomeIcons.trash),
                        onPressed: () {
                          this.widget.onClean();
                          _fieldTextEditingController.text = "";
                        }),
                    IconButton(
                        icon: Icon(FontAwesomeIcons.search),
                        onPressed: () {
                          Get.to(
                            () => SearchPage(
                              controller: widget.controller,
                              textColor: Colors.grey,
                              theme: widget.theme,
                              selected: (value) {
                                widget.selected(value);
                                _fieldTextEditingController.text =
                                    (value as ISearchTile).title;
                                Get.back();
                              },
                            ),
                          );
                        }),
                  ],
                ),
              ),
            )
          ],
        ),
      );
    });
  }
}
